@@ -470,9 +470,13 @@ class TestCase(object):
         else:  # mismatch
             if on_mismatch_verdict is not None:
                 def callback(path, mismatch, describe):
-                    self.log("             %s: %s\n" % (".".join(path), type(mismatch).__name__))
+                    #
                     # for i in diff_list:
                     #     self.log("             List Diff Item: %s\n" % (i))
+                    logger.info("errrrr")
+                    logger.info(path)
+                    logger.info(dir(path))
+                    self.log("             %s: %s\n" % (".".join(path), type(mismatch).__name__))
                     self.log("                 got:      %s\n" % mismatch.describe_value(describe))
                     self.log("                 expected: %s\n" % mismatch.describe_expected(describe))
 
@@ -482,7 +486,7 @@ class TestCase(object):
                     partial_verdict_message = template
 
                 # Put the verdict
-                self.set_verdict(on_mismatch_verdict, "%s Mismatch: %s" %(str(self._frame),partial_verdict_message))
+                self.set_verdict(on_mismatch_verdict, "%s Mismatch: %s" %(str(self._frame), partial_verdict_message))
                 diff_list.describe(callback)
 
 
@@ -588,10 +592,12 @@ class TestCase(object):
             expected_frames_pattern=self.get_stimulis()
         )
 
-        # print("----conversations----")
-        # print(self._conversations)
-        # print("----ignored----")
-        # print(self._ignored)
+        logging.debug('\n{}\n{}\n{}\n{}'.format(
+            "----conversations----",
+            self._conversations,
+            "----ignored----",
+            self._ignored
+        ))
 
         if self._conversations == [[]] or self._conversations == []:
             self.set_verdict(
@@ -604,12 +610,18 @@ class TestCase(object):
             # Run the test case for every conversations
             for conv in self._conversations:
                 if logger.getEffectiveLevel() == logging.DEBUG:
-                    for frame in conv: logger.debug(frame)
+                    for frame in conv:
+                        logger.debug(frame)
                 try:
                     # Get an iterator on the current conversation frames
                     # and its list of nodes
                     self._iter = iter(conv)
-                    self._nodes = conv.nodes
+
+                    try:
+                        self._nodes = conv.nodes
+                    except AttributeError:  # "relaxed" test cases have no nodes definition and that's ok
+                        pass
+
                     self.next()
 
                     # Run the test case
