@@ -209,7 +209,6 @@ class InetType (__OptFieldRefTag):
 		assert self.__bidict is not None  # must have been initialised
 
 		v = seq if self.get_ref_id() is None else values_bins[self.get_ref_id()][0]
-
 		return self.__bidict[:v.get_type()]
 
 	def post_decode (self, ctx, value):
@@ -219,6 +218,7 @@ class InetType (__OptFieldRefTag):
 
 		if self.get_ref_id() is not None:
 			# set a handler -> a 'with' context to change the slice on the fly
+			logging.info("~context~ pushing to context expected type {}".format(expected_type))
 			ctx.push_context (self.get_ref_id(), self.__decode_context (ctx, expected_type))
 		else:
 			# try to change the type on the fly
@@ -253,19 +253,7 @@ class InetType (__OptFieldRefTag):
 			# change the variant
 			ctx.variant = expected_type
 
-		print("~~~context Inet().postdecode {}~~~".format(self.get_ref_id))
-		print(ctx.variant)
-		print(ctx.expected_type)
-		# print(dir(ctx.values))
-		# for f in ctx.values:
-		# 	print(f.display())
-		# print(dir(f))
-		# print(ctx.variant)
-		# print(ctx.initial_slice)
-		# print(ctx.remaining_slice)
-		# print(ctx.expected_type)
-		# print(ctx.expected_count)
-		# print("~~~ end ~~~")
+		logging.info("~context~ Post decode of {} - {}".format(ctx.variant,self.get_ref_id))
 
 class InetVariant (InetType):
 	def __init__ (self):
@@ -342,17 +330,7 @@ class InetLength (__OptFieldRefTag):
 			# set a handler -> a 'with' context ! to change the slice on the fly
 			ctx.push_context (self.get_ref_id(), self.__decode_context (ctx, value))
 
-		print("~~~context InetLength().postdecode {}~~~".format(self.get_ref_id))
-		print(ctx.variant)
-		print(ctx.expected_type)
-		# print(dir(ctx.values))
-		# for f in ctx.values:
-		# 	print(f.display())
-		# print(dir(f))
-		# print(ctx.variant)
-		# print(ctx.initial_slice)
-		# print(ctx.remaining_slice)
-		# print(ctx.expected_count)
+		logging.info("~context~ Post decode of {} - {}".format(ctx.variant, self.get_ref_id))
 
 class InetCount (__OptFieldRefTag):
 	@staticmethod
@@ -653,7 +631,7 @@ class InetPacketValue (PacketValue):
 		:param bin_slice:
 		:return:
 		"""
-		logging.debug("Default decode mechanism from meta")
+		logging.debug("Default decoding mechanism for Values which are InetPacketValues")
 
 		ctx = _DecodeContext ()
 		ctx.expected_type	= None
